@@ -66,8 +66,7 @@ else:
     from sqlalchemy import select
 
     from airflow.auth.managers.models.resource_details import AccessView
-    from airflow.models.taskinstance import TaskInstanceState
-    from airflow.utils.state import State
+    from airflow.utils.state import State, TaskInstanceState
     from airflow.utils.yaml import safe_load
     from airflow.www.auth import has_access_view
 
@@ -252,18 +251,10 @@ class EdgeExecutorPlugin(AirflowPlugin):
             fastapi_apps = [_get_api_endpoint()]
             react_apps = [
                 {
-                    "name": "Edge Worker",
+                    "name": "Edge Executor",
                     "bundle_url": _get_base_url_path("/edge_worker/static/main.umd.cjs"),
                     "destination": "nav",
-                    "url_route": "edge_worker",
-                    "category": "admin",
-                    "icon": _get_base_url_path("/edge_worker/res/cloud-computer.svg"),
-                    "icon_dark_mode": _get_base_url_path("/edge_worker/res/cloud-computer-dark.svg"),
-                },
-                {
-                    "name": "Edge Worker Jobs",
-                    "bundle_url": _get_base_url_path("/edge_worker/static/main.umd.cjs"),
-                    "url_route": "edge_jobs",
+                    "url_route": "edge_executor",
                     "category": "admin",
                     "icon": _get_base_url_path("/edge_worker/res/cloud-computer.svg"),
                     "icon_dark_mode": _get_base_url_path("/edge_worker/res/cloud-computer-dark.svg"),
