@@ -39,7 +39,6 @@ from airflow.providers.edge3.worker_api.routes._v2_compat import (
     status,
 )
 from airflow.stats import Stats
-from airflow.utils.sqlalchemy import with_row_locks
 from airflow.utils.state import TaskInstanceState
 
 jobs_router = AirflowRouter(tags=["Jobs"], prefix="/jobs")
@@ -78,8 +77,8 @@ def fetch(
     if body.queues:
         query = query.where(EdgeJobModel.queue.in_(body.queues))
     query = query.limit(1)
-    query = with_row_locks(query, of=EdgeJobModel, session=session, skip_locked=True)
-    job: EdgeJobModel = session.scalar(query)
+    query = query.with_for_update(skip_locked=True)
+    job: EdgeJobModel | None = session.scalar(query)
     if not job:
         return None
     job.state = TaskInstanceState.RUNNING
@@ -148,7 +147,7 @@ def state(
             )
             Stats.incr("edge_worker.ti.finish", tags=tags)
 
-    query = (
+    query2 = (
         update(EdgeJobModel)
         .where(
             EdgeJobModel.dag_id == dag_id,
@@ -159,4 +158,4 @@ def state(
         )
         .values(state=state, last_update=timezone.utcnow())
     )
-    session.execute(query)
+    session.execute(query2)
